from setuptools import setup

setup(name='udacity_probability_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['udacity_probability_distributions'],
	  author='Ravi Bansal',
      zip_safe=False)
